module Gitlab
  module Mercurial

    NULL_NODE = ('00' * 20).freeze

    BookmarksUnsupportedError = Class.new(StandardError)

    class << self
      # Suitable value for HGRCPATH so that structural and default settings
      # are loaded and an application wide can override them.
      def hgrc_path
        Gitlab.config.mercurial.hgrc.join(":")
      end

      def parse_gitlab_branch_for_hg(gitlab_branch)
        if gitlab_branch.start_with?('branch/')
          [gitlab_branch[7..], nil]
        elsif gitlab_branch.start_with?('topic/')
          branch, _slash, topic = gitlab_branch[6..].rpartition('/')
          [branch, topic]
        else
          raise BookmarksUnsupportedError, gitlab_branch
        end
      end
    end
  end
end
