# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Gitlab::Mercurial do

  before do
    cls = Class.new(Object)
    cls.send(:include, Gitlab::Popen)
    @popen = cls.new
  end

  describe 'config.mercurial.hgrc' do
    it 'points to existing files' do
      Gitlab.config.mercurial.hgrc.each do |path|
        expect(File.exist?(path)).to be(true)
      end
    end
  end

  describe '.hgrc_path' do
    let(:hg_env) { {'HGRCPATH' => described_class.hgrc_path} }
    let(:hg_exe) { Gitlab.config.mercurial.bin_path }

    it 'activates the wished extensions' do
      cmd = [hg_exe, 'debugextensions']
      out, status = @popen.popen(cmd, nil, hg_env)
      expect(status).to eq(0)
      expect(out).to include("heptapod (untested!)")
    end

    it 'sets the required local settings' do
      env = {'HGRCPATH' => described_class.hgrc_path}
      cmd = [Gitlab.config.mercurial.bin_path, 'config', 'heptapod']
      out, status = @popen.popen(cmd, '/', env)
      expect(status).to eq(0)
      expect(out).to include("gitlab-internal-api-secret-file")
    end
  end
end
